@@ -1,4 +1,4 @@
-from .copy import *
+from .copy_file import *
 from .ipynb import *
 from .parse import *
 from .snip import *
