@@ -1,2 +1,2 @@
-from .copy import *
+from .copy_file import *
 from .json_ipynb import *
