@@ -2,13 +2,13 @@ from snip_copy.parse import *
 
 text = """ this text
 is across
-#! snip-start: a
+#! snip: a
 many lines and 
 periodically
 #! snip-end
 
 contains some command
-#! snip-start: a, b
+#! snip: a, b
 notice that we don't actually include a snip-end here
 """
 
@@ -16,9 +16,9 @@ line_list_expect = [' this text', 'is across', 'many lines and ',
                     'periodically', '', 'contains some command',
                     "notice that we don't actually include a snip-end here",
                     '']
-cmd_list_expect = [Command(type='snip-start', line_idx=2, args=['a']),
+cmd_list_expect = [Command(type='snip', line_idx=2, args=['a']),
                    Command(type='snip-end', line_idx=4, args=None),
-                   Command(type='snip-start', line_idx=6, args=['a', 'b'])]
+                   Command(type='snip', line_idx=6, args=['a', 'b'])]
 
 
 def test_parse():
